﻿$(document).ready(function () {

    var selectedIds = [];

    var projectsDatatable = $('#projectsDatatable').DataTable({
        "language": {
            "processing": "Loading data...",
        },
        "stateSave": true,
        "pageLength": 25,
        "lengthMenu": [0, 5, 10, 25, 50, 100, 200, 500],
        "select": true,
        "searching": false,
        "scrollX": true,
        "autoWidth": true,
        "processing": true,
        "serverSide": true,
        "filter": true,
        "ajax": {
            "url": "/api/projects",
            "type": "POST",
            "datatype": "json"
        },
        "columnDefs": [
            { "targets": [0], "orderable": false, "searchable": false, },
            { "targets": [1], "visible": false, "searchable": false, },
            {
                "targets": [4, 5],
                render: function (data, type, row) {
                    if (data) {
                        return type === 'display' && data.length > 50 ?
                            data.substr(0, 50) + '…' :
                            data;
                    }
                    else {
                        return " ";
                    }
                }
            },
        ],
        "columns": [
            {
                "render": function (data, type, row, meta) {
                    return `<a href="./Select?projectId=` + row.id + `" type="button" class="btn btn-success btn-sm" title="Select"><span class="fas fa-hand-pointer"></span></a>
<a href="./View?id=` + row.id + `" type="button" class="btn btn-secondary btn-sm" title="View"><span class="far fa-eye"></span></a>

`;
                }
            },
            { "data": "id", "name": "Id" },
            { "data": "name", "name": "Name" },
            { "data": "status", "name": "Status" },
            { "data": "description", "name": "Description" },
            { "data": "notes", "name": "Notes" },
            { "data": "updatedDate", "name": "Updated", "type": "Date" },
            { "data": "createdDate", "name": "Created", "type": "Date" },
        ],
    });

    /*
     * Handle table select
     * */
    projectsDatatable.on('select.dt', function (e, dt, type, indexes) {
        if (type === 'row') {
            selectedIds.length = 0; //Clear the array first
            var data = projectsDatatable.rows({ selected: true }).data().pluck('id'); //Go through ALL rows to see which are selected

            for (let i = 0; i < data.length; i++) {
                if (!selectedIds.includes(data[i])) { //Only add if not already added
                    selectedIds.push(data[i]);
                }
            }
        }
    });

    /*
     * Handle table deselect
     * */
    projectsDatatable.on('deselect.dt', function (e, dt, type, indexes) {
        if (type === 'row') {
            var data = projectsDatatable.rows(indexes).data().pluck('id');

            for (let i = 0; i < data.length; i++) {
                var index = selectedIds.indexOf(data[i]);
                if (index > -1) {
                    selectedIds.splice(index, 1);
                }
            }
        }
    });

    /*
 * Show/hide columns
 * */
    $('button.toggle-vis').on('click', function (e) {
        e.preventDefault();

        // Get the column API object
        var column = projectsDatatable.column($(this).attr('data-column'));

        // Toggle the visibility
        column.visible(!column.visible());
    });

    $('input.toogle-column-visibility').on('click', function (e) {
        // Get the column API object
        var column = projectsDatatable.column($(this).attr('data-column'));

        // Toggle the visibility
        column.visible(!column.visible());
    });

    $('button.toogle-column-visibility-select-special').on('click', function (e) {
        if (this.id === "customSwitchShowAll") {
            showAllColumns();
        }
        else if (this.id === "customSwitchHideAll") {
            hideAllColumns();
        }
    });

    /*
     * Set correct state on visibility switches when modul loads
     * */
    $('a.show-hide-columns').on('click', function (e) {
        setCorrectSwitchStates();
    });

    function setCorrectSwitchStates() {
        var allCheckboxes = document.getElementsByClassName("toogle-column-visibility");

        for (let i = 0; i < allCheckboxes.length; i++) {
            var column = projectsDatatable.column($(allCheckboxes[i]).attr('data-column'));
            var isVisible = column.visible();
            if (isVisible == true) {
                allCheckboxes[i].checked = true;
            }
            else {
                allCheckboxes[i].checked = false;
            }
        }
    }

    function showAllColumns() {
        projectsDatatable.columns().visible(true);
        var allCheckboxes = document.getElementsByClassName("toogle-column-visibility");
        projectsDatatable.columns([1]).visible(false); //Exceptions, always hide this column
        for (let i = 0; i < allCheckboxes.length; i++) {
            allCheckboxes[i].checked = true;
        }
    }

    function hideAllColumns() {
        projectsDatatable.columns().visible(false);
        projectsDatatable.columns([0]).visible(true); //Exceptions, never hide this column
        var allCheckboxes = document.getElementsByClassName("toogle-column-visibility");

        for (let i = 0; i < allCheckboxes.length; i++) {
            allCheckboxes[i].checked = false;
        }
    }



});