﻿$(document).ready(function () {

    var selectedIds = [];

    var aId = $('#assessmentId').text();

    var scansDatatable = $('#scansDatatable').DataTable({
        "language": {
            "processing": "Loading data...",
        },
        "stateSave": true,
        "pageLength": 25,
        "lengthMenu": [0, 5, 10, 25, 50, 100, 200, 500],
        "select": true,
        "searching": false,
        "scrollX": true,
        "autoWidth": true,
        "processing": true,
        "serverSide": true,
        "filter": true,
        "ajax": {
            "url": "/api/scans",
            "type": "POST",
            "datatype": "json",
            "data": {
                assessmentId: aId
            }
        },
        "columnDefs": [
            { "targets": [0], "visible": false, "searchable": false, },
            { "targets": [1], "orderable": false, "searchable": false, },
        ],
        "columns": [
            { "data": "id", "name": "Id" },
            {
                "render": function (data, type, row, meta) {
                    return `<a href="./View?id=` + row.id + `" type="button" class="btn btn-secondary btn-sm" title="View"><span class="far fa-eye"></span></a>
<a href="./Delete?id=` + row.id + `" type="button" class="btn btn-danger btn-sm" title="Delete"><span class="fas fa-fw fa-trash"></span></a>
<a href="/vulnerabilities/list?scanId=` + row.id + `" type="button" class="btn btn-secondary btn-sm" title="View Vulnerabilities"><i class="icon_table"></i></a>
<a href="./Select?scanId=` + row.id + `" type="button" class="btn btn-secondary btn-sm" title="Select"><span class="fas fa-hand-pointer"></span></a>
`;
                }
            },
            { "data": "name", "name": "Name" },
            { "data": "description", "name": "Description" },
        ],
    });

    /*
     * Handle table select
     * */
    scansDatatable.on('select.dt', function (e, dt, type, indexes) {
        if (type === 'row') {
            selectedIds.length = 0; //Clear the array first
            var data = scansDatatable.rows({ selected: true }).data().pluck('id'); //Go through ALL rows to see which are selected

            for (let i = 0; i < data.length; i++) {
                if (!selectedIds.includes(data[i])) { //Only add if not already added
                    selectedIds.push(data[i]);
                }
            }

            if (selectedIds.length > 1) {
                $('#btnEditMultipleHosts').removeClass('disabled');
                $('#btnEditMultipleHosts').attr("href", "./EditMultiple?hostsIds=" + selectedIds.toString());
            }

            console.log("Selected IDs " + selectedIds.toString());
        }
    });

    /*
     * Handle table deselect
     * */
    scansDatatable.on('deselect.dt', function (e, dt, type, indexes) {
        if (type === 'row') {
            var data = scansDatatable.rows(indexes).data().pluck('id');

            for (let i = 0; i < data.length; i++) {
                var index = selectedIds.indexOf(data[i]);
                if (index > -1) {
                    selectedIds.splice(index, 1);
                }
            }

            if (selectedIds.length < 2) {
                $('#btnEditMultipleHosts').addClass('disabled', 'disabled');
                $('#btnEditMultipleHosts').attr("href", "broken" + selectedIds.toString());
            }
            else {
                $('#btnEditMultipleHosts').attr("href", "./EditMultiple?hostsIds=" + selectedIds.toString());
            }

            console.log("Selected IDs " + selectedIds.toString());
        }
    });


    /*
     * Show/hide columns
     * */
    $('button.toggle-vis').on('click', function (e) {
        e.preventDefault();

        // Get the column API object
        var column = scansDatatable.column($(this).attr('data-column'));

        // Toggle the visibility
        column.visible(!column.visible());
    });

    $('input.toogle-column-visibility').on('click', function (e) {
        // Get the column API object
        var column = scansDatatable.column($(this).attr('data-column'));

        // Toggle the visibility
        column.visible(!column.visible());
    });

    /*
     * Set correct state on visibility switches when modul loads
     * */
    $('a.show-hide-columns').on('click', function (e) {
        var allCheckboxes = document.getElementsByClassName("toogle-column-visibility");

        for (let i = 0; i < allCheckboxes.length; i++) {
            var column = scansDatatable.column($(allCheckboxes[i]).attr('data-column'));
            var isVisible = column.visible();
            if (isVisible == true) {
                allCheckboxes[i].checked = true;
            }
            else {
                allCheckboxes[i].checked = false;
            }
        }
    });
});